The main_noisySBM() function is a core component of the noisysbmGGM package,
responsible for applying the greedy algorithm to estimate model parameters, perform node clustering,
and conduct a multiple testing procedure to infer the underlying graph. This function is versatile,
offering various options and providing useful outputs for further analysis
main_noisySBM(
X,
NIG = FALSE,
threshold = 0.5,
Nbrepet = 2,
rho = NULL,
tau = NULL,
a = NULL,
b = NULL,
c = NULL,
d = NULL,
n0 = 1,
eta0 = 1,
zeta0 = 1,
alpha = 0.1,
Qup = NULL,
nbCores = parallel::detectCores(),
nbOfZ = 12,
sigma0 = 1,
sigma1 = 1,
percentageOfPerturbation = 0.3,
verbatim = TRUE
)Athe adjacency matrix of the inferred graph
Zthe inferred clustering
thetathe parameters of the noisySBM at the end
Qthe number of clusters at the end
A p-square matrix containing the data
A Boolean. If FALSE (by default), the variance under the alternative hypothesis in assumed to be known. If TRUE, the variances under the alternatives are unknown and estimated with the NIG method
Threshold use when updating the latent graphs structure from l-values (by default threshold=0.5)
Number of times the algorithm is repeated (by default Nbrepet=2)
Hyperparameter of the non-NIG method (by default rho=1)
Hyperparameter of the non-NIG method (by default tau=1)
Hyperparameter of the NIG method (by default a=0)
Hyperparameter of the NIG method (by default b=1)
Hyperparameter of the NIG method (by default c=1)
Hyperparameter of the NIG method (by default d=1)
Hyperparameter (by default n0=1)
Hyperparameter (by default eta0=1)
Hyperparameter (by default zeta0=1)
Level of significance of the multiple testing procedure (by default alpha=0.1)
Maximal number of cluster (by default Qup =10)
Nb of cores to be used during calculations (by default nbCores=parallel::detectCores())
Nb of initialization (by default nbOfZ=12)
standard deviation under the null hypothesis (by default sigma0=1)
standard deviation under the alternative hypothesis in the non-NIG method (by default sigma1=1)
perturbation during initialization (by default percentageOfPerturbation=0.3)
print information messages
main_noisySBM(NSBMtest$dataMatrix,NIG=TRUE,Qup=10,nbOfZ=1,nbCores=1)
Run the code above in your browser using DataLab